<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.


/**
 * Simple Clock block definition
 *
 * @package    contrib
 * @subpackage block_simple_clock
 * @copyright  2010 Michael de Raadt
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once(dirname(__FILE__) . '/../../config.php');

// Three states, must show at least one clock
define('B_SIMPLE_CLOCK_SHOW_BOTH',        0);
define('B_SIMPLE_CLOCK_SHOW_SERVER_ONLY', 1);
define('B_SIMPLE_CLOCK_SHOW_USER_ONLY',   2);

/**
 * Simple clock block class
 *
 * @copyright 2010 Michael de Raadt
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class block_simple_clock extends block_base {

    /**
     * Sets the block title
     *
     * @return none
     */
    function init() {
        $this->title = get_string('clock_title_default', 'block_simple_clock');
    }

    /**
     * Defines where the block can be added
     *
     * @return array
     */
    function applicable_formats() {
        return array('all' => true);
    }

    /**
     * Constrols global configurability of block
     *
     * @return bool
     */
    function instance_allow_config() {
        return false;
    }

    /**
     * Constrols global configurability of block
     *
     * @return bool
     */
    function has_config() {
        return false;
    }

    /**
     * Constrols if a block header is shown based on instance configuration
     *
     * @return bool
     */
    function hide_header() {
        return isset($this->config->show_header) && $this->config->show_header==0;
    }

    /**
     * Constrols the block title based on instance configuration
     *
     * @return bool
     */
    function specialization() {
        $this->title = isset($this->config->clock_title)?
            $this->config->clock_title:
            get_string('clock_title_default', 'block_simple_clock');
    }

    /**
     * Creates the blocks main content
     *
     * @return string
     */
    function get_content() {

        // Access to settings needed
        global $USER, $COURSE, $OUTPUT, $CFG;

        if (isset($this->content)) {
            return $this->content;
        }

        // Settings variables based on config
        $showserverclock = !isset($this->config->show_clocks) ||
            $this->config->show_clocks==B_SIMPLE_CLOCK_SHOW_BOTH ||
            $this->config->show_clocks==B_SIMPLE_CLOCK_SHOW_SERVER_ONLY;
        $showuserclock = !isset($this->config->show_clocks) ||
            $this->config->show_clocks==B_SIMPLE_CLOCK_SHOW_BOTH ||
            $this->config->show_clocks==B_SIMPLE_CLOCK_SHOW_USER_ONLY;
        $showicons = !isset($this->config->show_icons) || $this->config->show_icons==1;
        $showseconds = isset($this->config->show_seconds) && $this->config->show_seconds==1;
        $showday = isset($this->config->show_day) && $this->config->show_day==1;

        $this->content = new stdClass;
        $this->content->text = '<table class="clockTable">';

        // First item is the server's clock
        if ($showserverclock) {
            $this->content->text .= '<tr>';
            if ($showicons) {
                $iconimage = $OUTPUT->pix_icon('favicon', 'Server icon', 'theme');
                $this->content->text .= '<td>'.$iconimage.'</td>';
            }
            $this->content->text .= '<td>'.get_string('server', 'block_simple_clock').':</td>';
            $this->content->text .= '<td><input class="clock" id="block_progress_serverTime"'.
                'value="'.get_string('loading', 'block_simple_clock').'" /></td>';
            $this->content->text .= '</tr>';
        }

        // Next item is the user's clock
        if ($showuserclock) {
            $this->content->text .= '<tr>';
            if ($showicons) {
                $this->content->text .= '<td>';
                if ($USER->id!=0) {
                    $userpictureparams = array('size'=>16, 'link'=>false, 'alt'=>'User');
                    $userpicture = $OUTPUT->user_picture($USER, $userpictureparams);
                    $this->content->text .= $userpicture;
                }
                $this->content->text .= '</td>';
            }
            $this->content->text .= '<td>'.get_string('you', 'block_simple_clock').':</td>';
            $this->content->text .= '<td><input class="clock" id="block_progress_youTime" value="'.
                get_string('loading', 'block_simple_clock').'" /></td>';
            $this->content->text .= '</tr>';
        }
        $this->content->text .= '</table>';

        // Set up JavaScript
        $this->content->text .= '<noscript>';
        $this->content->text .= get_string('javascript_disabled', 'block_simple_clock');
        $this->content->text .= '</noscript>';
        if ($CFG->timezone != 99) {
            // Ensure that the Moodle timezone is set correctly and
            // the correct server timezone is set in php.ini
            $moodletimeoffset = get_timezone_offset($CFG->timezone);
            $servertimeoffset = date_offset_get(new DateTime);
            $timearray = localtime(time() + $moodletimeoffset - $servertimeoffset, true);
        }
        else {
            // Ensure that the server timezone is set in php.ini
            $timearray = localtime(time(), true);
        }

        $arguments = array(
            $showserverclock,
            $showuserclock,
            $showseconds,
            $showday,
            $timearray['tm_year']+1900,
            $timearray['tm_mon'],
            $timearray['tm_mday'],
            $timearray['tm_hour'],
            $timearray['tm_min'],
            $timearray['tm_sec']+2 // arbitrary load time added
        );
        $jsmodule = array(
            'name' => 'block_simple_clock',
            'fullpath' => '/blocks/simple_clock/module.js',
            'requires' => array(),
            'strings' => array(
                array('clock_separator', 'block_simple_clock'),
                array('before_noon', 'block_simple_clock'),
                array('after_noon', 'block_simple_clock'),
                array('day_names', 'block_simple_clock'),
            ),
        );
        $this->page->requires->js_init_call('M.block_simple_clock.initSimpleClock',
                                            $arguments, false, $jsmodule);

        $this->content->footer = '';
        return $this->content;
    }
}
